#!/bin/sh

WAR_FILE="netvizura.war"

if [[ ! -e /var/log/netvizura ]]; then
    mkdir /var/log/netvizura
elif [[ ! -d /var/log/netvizura ]]; then
    echo "/var/log/netvizura already exists but is not a directory" 1>&2
fi

service tomcat6 stop
sed --in-place=.bak "s/ docBase=.*\"//" /etc/tomcat6/Catalina/localhost/netvizura.xml
cp ${WAR_FILE} /usr/share/tomcat6/webapps/netvizura.war

NETVIZURA_DIR="/usr/share/tomcat6/webapps/netvizura"
if [ -e $NETVIZURA_DIR ]
then
        rm -rf $NETVIZURA_DIR
fi


cd ./sql
bash ./patch.sh
cd ..


## open iptables port 33515 for End Users
if ! grep "\-\-dport 33515" /etc/sysconfig/iptables > /dev/null ; then
	echo "Opening iptables firewall port 33515 for End Users Syslog packets"
	iptables -I INPUT -p udp --dport 33515 -j ACCEPT
	sed --in-place=.bak '/-A INPUT -j REJECT --reject-with icmp-host-prohibited/i-A INPUT -p udp --dport 33515 -j ACCEPT' /etc/sysconfig/iptables
	echo "--port=33515:udp" >> /etc/sysconfig/system-config-firewall
fi

## restarting iptables for good measure
service iptables restart

# add new DBCP to Tomcat
if [ ! -e /usr/share/tomcat6/lib/tomcat-jdbc-*.jar ]
then
	cp jars/tomcat-jdbc-*.jar /usr/share/tomcat6/lib
fi

if [ ! -e /usr/share/tomcat6/lib/tomcat-dbcp-*.jar ]
then
	cp jars/tomcat-dbcp-*.jar /usr/share/tomcat6/lib
fi

tomcat_conf="/etc/tomcat6/tomcat6.conf"

### TOMCAT TWEAKS ###
# tweak Tomcat 6 to use new database pool
if ! grep -Fq "dbcp2" $tomcat_conf
then
	sed --in-place 's/^#\?\(.*apache\.\).*BasicDataSourceFactory\"$/#\0\n\1tomcat\.dbcp\.dbcp2\.BasicDataSourceFactory\"/' $tomcat_conf
fi

# Tomcat memory calculation
mem=`free -k  | grep Mem | awk  '{print $2}'`
k=1024
mem_in_m=$(( $(( $mem + $k - 1 )) / $k ))

tomcat_heap=$(( $(( $mem_in_m - 1024 )) /3 ))
if [ $tomcat_heap -lt 1024 ]
then
    tomcat_heap=1024
fi

rounded_heap=$(( $(( $(( $tomcat_heap + 255 )) / 256 )) * 256 ))
new_size=$(( $rounded_heap / 2 ))

# tweak heap allocation
if ! grep -Fq "Xms" $tomcat_conf
then
	heap1="# NetVizura: increasing Tomcat heap allocation"
	heap2='JAVA_OPTS="${JAVA_OPTS} '"-Xmx${rounded_heap}m -Xms${rounded_heap}m\""
	echo >> $tomcat_conf
	echo $heap1 >> $tomcat_conf
	echo $heap2 >> $tomcat_conf
fi

# tweak Java garbage collector and memory settings
if ! grep -Fq "MaxNewSize" $tomcat_conf
then
	gcmem1="# NetVizura: Java GC and memory settings"
	gcmem2='JAVA_OPTS="${JAVA_OPTS} '"-XX:+UseConcMarkSweepGC -XX:MaxNewSize=${new_size}m -XX:NewSize=${new_size}m -XX:SurvivorRatio=3 -XX:TargetSurvivorRatio=80 -XX:InitialTenuringThreshold=5 -XX:MaxTenuringThreshold=5\""
	echo >> $tomcat_conf
	echo $gcmem1 >> $tomcat_conf
	echo $gcmem2 >> $tomcat_conf
fi

# allow traversal of PostgreSQL directories - to get free space info
chmod +x /var/lib/pgsql
chmod +x /var/lib/pgsql/*

# tweak iptabes to allow REDIRECT on all interfaces
sed -i.bak 's/\(.*\)\( -i eth0\)\(.*514.*REDIRECT.*\)/\1\3/' /etc/sysconfig/iptables
sed -i.bak 's/\(.*\)\( -i eth0\)\(.*162.*REDIRECT.*\)/\1\3/' /etc/sysconfig/iptables
service iptables restart

# update to Java 8
# !!! Bitno !!!
# od sledeće verzije preseliti ovu sekciju na početak, s tim da se ne dozvoli nastavak update-a 
# ukoliko nema Jave 8

# check for java-1.8.0-openjdk

has_java8=1

yum list installed java-1.8.0-openjdk > /dev/null 2>&1

if [ $? -eq 1 ]
then
	# check for Oracle Java 8
	ls /usr/java/ | grep jdk1.8 > /dev/null 2>&1
	if [ $? -eq 1 ]
	then
		has_java8=0
	fi
fi

if [ $has_java8 -eq 0 ]
then

	# try installing OpenJDK 8
	yum -y install java-1.8.0-openjdk

	if [ $? -eq 0 ]
	then
        	# OpenJDK 8 installation OK
	        sudo sed -i 's/JAVACMD=\/usr\/java\/latest\/bin\/java/set_javacmd/' /usr/sbin/tomcat6
        	if alternatives --display java | grep $(readlink /usr/java/latest) >> /dev/null
	        then
        	        sudo alternatives --remove java $(readlink /usr/java/latest)/jre/bin/java
                	sudo rm -f /etc/.netvizura/.iclick
	                sudo mv /var/lib/netvizura/active.key /var/lib/netvizura/license.key
        	fi
	else
        	# OpenJDK 8 installation failed
		# Should we try Oracle Java 8? TODO
	        whiptail --fb --ok-button "Understood" --title "NetVizura Java 7 deprecation" --backtitle "Important information on Java 7 and NetVizura" --msgbox "NetVizura deprecated support for Java 7. We recommend installation of OpenJDK 8 instead. More info: https://confluence.netvizura.com/x/gYad#java7-deprecation" 12 80
	fi
fi
# end update to Java 8

service tomcat6 start

